@@ -1,10 +1,11 @@
 from __future__ import annotations
+from exodusutils.schemas.input_file import InputFile
 
 import json
 import traceback
 from enum import Enum
 from logging import Logger
-from typing import Awaitable, Callable, Dict, List, Optional
+from typing import Any, Awaitable, Callable, Dict, List, Optional
 
 import pandas as pd
 import requests
@@ -50,8 +51,8 @@ class TrainReqBodyBase(AwaitableReq):
 
     Attributes
     ----------
-    training_data : bytes
-        The training data as a sequence of bytes.
+    training_data : str
+        The URI for the training data.
     feature_types : List[Column]
         The features present in training data.
     target : Column
@@ -62,9 +63,11 @@ class TrainReqBodyBase(AwaitableReq):
 
     training_data: str = Field(description="The training data uri")
     feature_types: List[Column] = Field(
-        default=[], description="The features present in training data"
+        default=[Column(name="foo", data_type="double")],
+        description="The features present in training data"
     )
     target: Column = Field(
+        default=Column(name="foo", data_type="double"),
         description="The target column. Must be present in feature_types"
     )
     folds: int = Field(
@@ -157,30 +160,43 @@ class TrainIIDReqBody(TrainReqBodyBase):
         description="The name of the fold assignment column. If not provided, Exodus will cut cross validation folds in a modulo fashion. If this field is defined, it is required to be a valid column in the input dataframe. This column is not included in `feature_types`, and will be discarded during training.",
     )
 
-    @validator("fold_assignment_column_name")
-    def validate_fold_column(cls, v, values):
-        if v is not None:
-            data = values["training_data"]
-            header = data.decode("utf-8").split("\n")[0].split(",")
-            if v not in header:
-                raise ExodusBadRequest(
-                    f"fold assignment column = {v} not found in header"
-                )
-        return v
-
     class Config:
         schema_extra = {
             "examples": [
                 {
-                    "training_data": "foo,bar\n0,abc\n1,def\n2,ghi\n3,jkl\n4,mnop\n5,qrs\n",
-                    "feature_types": [
-                        {"name": "foo", "data_type": "double"},
-                        {"name": "bar", "data_type": "string"},
-                    ],
-                    "target": [{"name": "bar", "data_type": "string"}],
-                    "folds": 3,
-                    "validation_percentage": 0.2,
-                    "holdout_data": "foo,bar\n99,zzz\n",
+                    "req": {
+                        "training_data": "s3a://some-bucket/foo/bar/train.csv",
+                        "feature_types": [
+                            {"name": "foo", "data_type": "double"},
+                            {"name": "bar", "data_type": "string"},
+                        ],
+                        "target": [{"name": "foo", "data_type": "double"}],
+                        "folds": 3,
+                        "holdout_data": "s3a://some-bucket/foo/bar/holdout.csv"
+                    }
+                },
+                {
+                    "req": {
+                        "training_data": "don\'t care",
+                        "feature_types": [
+                            {"name": "don\'t care", "data_type": "double"},
+                        ],
+                        "target": [{"name": "don\'t care", "data_type": "double"}],
+                        "folds": 5,
+                        "holdout_data": "s3a://some-bucket/foo/bar/holdout.csv"
+                    },
+                    "simple_request": {
+                        "config_path": "/home/foo/bar/config.json",
+                        "training_file": {
+                            "path": "/home/foo/bar/train.csv",
+                        },
+                        "holdout_file": {
+                            "path": "/home/foo/bar/holdout.csv",
+                        },
+                        "validation_file": {
+                            "path": "/home/foo/bar/validation.csv",
+                        }
+                    }
                 }
             ]
         }
@@ -257,3 +273,65 @@ class MigrateReqBody(BaseModel):
 
     class Config:
         use_enum_values = True
+
+description = """
+The path to the local configuration file.
+
+The JSON file should contain the following:
+- **features**: A `dict` from `name` to `data_type` for all the column you wish to use.
+- **target_column_name**: The `name` of the target column.
+- **keep_cols**: The name of the columns you wish to keep.
+- **folds**: The number of folds you want to train with.
+"""
+
+
+class SimpleIIDTrainRequest(BaseModel):
+    """
+    Contains the following:
+    - Absolute path to a local JSON file containing the configuration values
+    - A `InputFile` object containing the absolute path to the local input training CSV file.
+    - A optional `InputFile` object containing the absolute path to the local input holdout CSV file.
+    - A optional `InputFile` object containing the absolute path to the local input validation CSV file.
+    """
+    config_path: str = Field(description=description)
+    training_file: InputFile = Field(description="The absolute path to the local input training file.")
+    holdout_file: Optional[InputFile] = Field(description="The absolute path to the local input holdout file. Optional", default=None)
+    validation_file: Optional[InputFile] = Field(description="The absolute path to the local input validation file. Optional", default=None)
+    _minio: Any = None
+
+    def __call__(self, minio: Minio):
+        """
+        Loads the JSON config into a `TrainIIDReqBody`.
+        """
+        self._minio = minio
+
+    def __enter__(self):
+        return self.load()
+
+    def __exit__(self, *args):
+        self.training_file.delete(self._minio)
+        if self.holdout_file is not None:
+            self.holdout_file.delete(self._minio)
+        if self.validation_file is not None:
+            self.validation_file.delete(self._minio)
+        return self
+
+
+    def load(self):
+        with open(self.config_path) as f:
+            meta_data = json.loads(f.read())
+            features = meta_data["features"]
+            feature_types = [{"name": k, "data_type": v} for k, v in features.items()]
+            target = [f for f in feature_types if f["name"] == meta_data["target_column_name"]][0]
+        training_data = self.training_file.upload(self._minio)
+        validation_data = None if self.validation_file is None else self.validation_file.upload(self._minio)
+        holdout_data = None if self.holdout_file is None else self.holdout_file.upload(self._minio)
+        return TrainIIDReqBody(
+            training_data=training_data,
+            target=target,
+            feature_types=feature_types,
+            folds=int(meta_data.get("folds", 5)),
+            validation_data=validation_data,
+            holdout_data=holdout_data,
+            fold_assignment_column_name=meta_data.get("fold_assignment_column_name", None)
+        )
