@@ -1,3 +1,4 @@
+import abc
 from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel
@@ -14,7 +15,13 @@ class Attributes(BaseModel):
     holdout_scores: Optional[Scores] = None
 
 
-class TrainRespBody(BaseModel):
+class ModelRespBase(BaseModel, abc.ABC):
+    """
+    The base class for all model algorithm responses.
+    """
+
+
+class TrainRespBody(ModelRespBase):
     """
     The schema for train response body.
     """
@@ -27,7 +34,7 @@ class TrainRespBody(BaseModel):
     )
 
 
-class PredictRespBody(BaseModel):
+class PredictRespBody(ModelRespBase):
     """
     The schema for prediction response body.
     """
@@ -42,3 +49,20 @@ class InfoRespBody(BaseModel):
 
     name: str = Field(description="Name of the model algorithm")
     description: str = Field(description="Description of the model algorithm")
+
+
+class FailedResp(BaseModel):
+    """
+    The schema for failed actions.
+    """
+
+    reason: str
+
+
+class OKResp(BaseModel):
+    """
+    The return value for train and predict. Notice how this does not contain any information,
+    as both actions are done asynchronously.
+    """
+
+    msg: str = "OK"
